@@ -20,14 +20,11 @@
 
 import vmp
 
-class Data:
-  def __init__(self):
-    self.th=None
+
 
 ##required    
 def vmp_main():
-  data=Data()
-  vmp.instance_.set_global(data)
+  data=vmp.instance_.get_global()
   vmp.debug('example_py run')
   vmp.output("{0}".format(vmp.UINTMAX))
   vmp.exit_ok()
