@@ -181,7 +181,7 @@ clibs_[moduleslib.name]=moduleslib
 jsonlib=clib()
 jsonlib.name='json'
 jsonlib.dependencies=['vmp','net','packet']
-jsonlib.files=[('./',['json','jdata','jtable','jlist'])]
+jsonlib.files=[('./',['json','japi','jdata','jtable','jlist'])]
 jsonlib.libs=[('json-c','0.15')]
 jsonlib.loptions=['`pkg-config json-c --cflags --libs`']
 clibs_[jsonlib.name]=jsonlib
