@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 12/02/2020
+#Date last Update : 03/11/2022
 
 ##@package vmp
 #
@@ -42,6 +42,7 @@ from vmp_ import Buf as Buf
 from vmp_ import except_s  as except_s
 
 from vmp_ import init               as init
+from vmp_ import is_debug_mode      as is_debug_mode
 from vmp_ import io_forced_unlock   as io_forced_unlock
 from vmp_ import debug              as debug
 from vmp_ import info               as info
@@ -57,6 +58,8 @@ from vmp_ import input_file         as input_file
 from vmp_ import input_file_s       as input_file_s
 from vmp_ import exit_ok            as exit_ok
 from vmp_ import exit_failure       as exit_failure
+from vmp_ import copy_file          as copy_file
+from vmp_ import move_file          as move_file
 
 from vmp_ import system_wrap  as system_wrap
 from vmp_ import pause_wrap   as pause_wrap
@@ -81,11 +84,17 @@ from vmp_ import unicode      as unicode
 
 from vmp_ import utils        as utils
 
+##Default Global data instance class object
+class Data:
+  ##A constructor 
+  def __init__(self):
+    pass
+    
 ##Global instance class 
 class Instance:
   ##A constructor  
   def __init__(self):
-    self.obj=None
+    self.obj=Data()
 
   ##set global data object<BR>
   #
