@@ -30,7 +30,7 @@
 //!Python wrapper of the c++ class vampiria::event::Manager in vmp_event.Manager(see c++ doc)
 /*!
     Manager class in event.h:<BR>Constructor Manager()<BR>
-    Manager member function list:<BR>lock(),unlock(),time_now(),breakloop(),stop(),loop()
+    Manager member function list:<BR>init(),lock(),unlock(),time_now(),breakloop(),stop(),loop()
 */
 void event_init_manager(pylib::Module module);
 
