@@ -190,6 +190,52 @@ struct stub_JData_get_vars:public pylib::Member_def<json::JData>
     }
 };
 
+struct stub_JData_set_subtype:public pylib::Member_def<json::JData>
+{
+    pylib::Objref *def(json::JData *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 2)
+        {
+            vmp::str label=args.get<vmp::str>(0);
+            json::JsonObj *jdata=args.get<json::JsonObj *>(1);
+            instance->set_subtype(label,jdata);
+            return pylib::retnone();                      
+        }
+        else if(args.size() == 3)
+        {
+            vmp::str label=args.get<vmp::str>(0);
+            json::JsonObj *jdata=args.get<json::JsonObj *>(1);
+            vmp::str jtype=args.get<vmp::str>(2);
+            instance->set_subtype(label,jdata,jtype);
+            return pylib::retnone(); 
+        }
+        return 0;
+    }
+};
+
+struct stub_JData_get_subtype:public pylib::Member_def<json::JData>
+{
+    pylib::Objref *def(json::JData *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 2)
+        {
+            vmp::str label=args.get<vmp::str>(0);
+            json::JsonObj *jdata=args.get<json::JsonObj *>(1);
+            instance->get_subtype(label,jdata);
+            return pylib::retnone();                      
+        }
+        else if(args.size() == 3)
+        {
+            vmp::str label=args.get<vmp::str>(0);
+            json::JsonObj *jdata=args.get<json::JsonObj *>(1);
+            vmp::str jtype=args.get<vmp::str>(2);
+            instance->get_subtype(label,jdata,jtype);
+            return pylib::retnone(); 
+        }
+        return 0;
+    }
+};
+
 void json_jdata(pylib::Module module)
 {
     pylib::Class<json::JData> jdata=module.class_<json::JData>("JData");
@@ -209,6 +255,8 @@ void json_jdata(pylib::Module module)
     jdata.def_("get_real",&json::JData::get_real);
     jdata.def_("set_real_range",&json::JData::set_real_range);
     jdata.def_("get_real_range",&json::JData::get_real_range);
+    jdata.def_("set_bool",&json::JData::set_bool);
+    jdata.def_("get_bool",&json::JData::get_bool);
     jdata.def_with_stub("new_list",stub_JData_new_list());
     jdata.def_with_stub("set_list",stub_JData_set_list());
     jdata.def_with_stub("get_list",stub_JData_get_list());
@@ -221,6 +269,8 @@ void json_jdata(pylib::Module module)
     jdata.def_with_stub("get_vars",stub_JData_get_vars());
     jdata.def_("set_custom",&json::JData::set_custom);
     jdata.def_("get_custom",&json::JData::get_custom);
+    jdata.def_with_stub("set_subtype",stub_JData_set_subtype());
+    jdata.def_with_stub("get_subtype",stub_JData_get_subtype());
     jdata.def_("set_buf",&json::JData::set_buf);
     jdata.def_("get_buf",&json::JData::get_buf);
     jdata.def_("set_netaddress",&json::JData::set_netaddress);
