@@ -182,6 +182,21 @@ class JData
             @return primitive value or except in case of failure
         */
         vmp_real get_real_range(vmp::str label,vmp_real min,vmp_real max);
+
+        //! Insert an boolean in jbody
+        /*!
+            @param label primitive label
+            @param value primitive value
+            @return void or except in case of failure
+        */  
+        void set_bool(vmp::str label,vmp_bool value);
+
+        //! Gets an boolean in jbody
+        /*!
+            @param label primitive label
+            @return primitive value or except in case of failure
+        */
+        vmp_bool get_bool(vmp::str label);
         
         //! Create a empty list primitive in the jbody.
         /*!
@@ -268,7 +283,7 @@ class JData
         */        
         void get_vars(vmp::str label,vmp::Table<vmp::str,vmp::str> *vars);
         
-        //! Insert a json object primitive in the jbody(custom json object).
+        //! Insert a json object primitive in the jbody(custom json object).if obj == 0 create empty custom object
         /*!
             @param label primitive label
             @param obj json object to insert
@@ -276,14 +291,32 @@ class JData
         */
         void set_custom(vmp::str label,json::JsonObj *obj);
 
-        //! Gets a json object primitive in the jbody(custom json object).
+        //! Gets an pointer json object primitive in the jbody(custom json object).
         /*!
             @param label primitive label
-            @param obj json object output
+            @param obj json object output(json object memory must be allocated to a json parser)
             @return void or except in case of failure
         */        
         void get_custom(vmp::str label,json::JsonObj *obj);
 
+        //! Insert a json data object(subtype)in the jbody.
+        /*!
+            @param label primitive label
+            @param jdata json data object
+            @param jtype type of json data object (jtype="" jdata object not typed)
+            @return void or except in case of failure
+        */
+        void set_subtype(vmp::str label,json::JsonObj *jdata,vmp::str jtype="");
+
+        //! Gets an pointer json data object(subtype) in the jbody.
+        /*!
+            @param label primitive label
+            @param jdata json data object output(
+            @param jtype type of json data object (jtype="" jdata object not typed)
+            @return void or except in case of failure
+        */
+        void get_subtype(vmp::str label,json::JsonObj *jdata,vmp::str jtype="");
+
         //! Insert a buffer primitive in the jbody.
         /*!
             @param label primitive label
