@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 27/02/2020
+ * Date last update: 25/09/2022
  */
 
 #ifndef VAMPIRIA_NET_ADDRESS_H
@@ -34,6 +34,14 @@ typedef struct sockaddr Sockaddr;/*!< struct sockaddr type(see linux doc)*/
 */
 vmp_bool is_ipv4_raw(vmp::str ip);
 
+//! It takes an ipv4 network in subnet mask format and returns the list of IPs associated with the network
+/*!
+    @param subnet subnet ipv4
+    @param mask network mask(0-32)
+    @return ipv4 address list
+*/
+vmp::vector<vmp::str> ipv4_expand(vmp::str subnet,vmp_uint mask);
+
 //!Check if the input string is an ipv6 address
 /*!
     @param ip input string
