@@ -40,7 +40,7 @@ pylib::Objref *none()
 
 vmp_bool is_none(pylib::Objref *ref)
 {
-    if(ref ==  Py_None)
+    if(ref == Py_None)
         return true;
     return false;
 }
@@ -346,6 +346,7 @@ pylib::Objref *pylist_new(vmp_size size)
         pylib::pyerr_clear();
         vmp::except_s("pylist_new error create list");
     }
+    pylib::incref(list);
     return list;
 }
 
@@ -402,6 +403,7 @@ void pylist_clear(pylib::Objref *list)
         }
     }
     pylib::decref(list);
+    pylib::pyerr_clear();
 }
 
 pylib::Objref *pylist_astuple(pylib::Objref *list)
@@ -448,6 +450,7 @@ pylib::Objref *pydict_new()
         pylib::pyerr_clear();
         vmp::except_s("pydict_new error create dict");
     }
+    pylib::incref(dict);
     return dict;   
 }
 
