@@ -64,8 +64,10 @@ template<typename T>
 void pyobj_setattr(pylib::Objref *obj,vmp::str name,T value)
 {
     pylib::Objref *ovalue=pylib::Converter<T>(value);
+    pylib::incref(ovalue);
     if(PyObject_SetAttrString(obj,name.c_str(),ovalue) == -1)
     {    
+        pylib::decref(ovalue);
         pylib::pyerr_clear();
         vmp::except("pyobj_setattr error insert '%s' value",name.c_str());
     }
@@ -79,7 +81,7 @@ T pyobj_getattr(pylib::Objref *obj,vmp::str name)
     pylib::Objref *ref=PyObject_GetAttrString(obj,name.c_str());
     if(ref == 0)
     {
-	pylib::pyerr_clear();
+        pylib::pyerr_clear();
         vmp::except("pyobj_getattr error get value '%s' not found ",name.c_str());
     }
     return pylib::arg_from_python<T>(ref);
@@ -104,8 +106,11 @@ void pylist_setitem(pylib::Objref *list,vmp_index pos,T value,vmp_bool retfree=t
         vmp::except_s("pylist_setitem error input objref not list type");
     try
     {
-        if(PyList_SetItem(list,pos,pylib::Converter<T>(value,retfree)) == -1)
+        pylib::Objref *ovalue=pylib::Converter<T>(value,retfree);
+        pylib::incref(ovalue);
+        if(PyList_SetItem(list,pos,ovalue) == -1)
         {
+            pylib::decref(ovalue);
             pylib::pyerr_clear();
             vmp::except("error set objref index %d",pos);
         }
@@ -138,8 +143,14 @@ void pydict_setitem(pylib::Objref *dict,Key key,Data data,vmp_bool kretfree=true
        vmp::except_s("pydict_setitem error input objref not dict type");
    try
    {
-       if(PyDict_SetItem(dict,pylib::Converter<Key>(key,kretfree),pylib::Converter<Data>(data,dretfree)) == -1)
+       pylib::Objref *kvalue=pylib::Converter<Key>(key,kretfree);
+       pylib::incref(kvalue);
+       pylib::Objref *ovalue=pylib::Converter<Data>(data,dretfree);
+       pylib::incref(ovalue);
+       if(PyDict_SetItem(dict,kvalue,ovalue) == -1)
        {
+           pylib::decref(kvalue);
+           pylib::decref(ovalue);
            pylib::pyerr_clear();
            vmp::except_s("error set item value"); 
        }
