@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 09/12/2019
+   Date last update: 03/11/2022
  */
 
 #include <stdio.h>
@@ -29,13 +29,19 @@
 
 namespace vampiria { namespace vmp {
 
-//! init module                
+//! init process                
 /*!
-    @param id module identified
+    @param id process identified
     @param debug debug mode?(true|false).                
 */
 void init(vmp::str id,vmp_bool debug=false);
 
+//! Check if the process is debugging mode
+/*!
+    @return true is debugging mode,otherwise false
+*/
+vmp_bool is_debug_mode();
+
 //!Format string value(printf style)
 /*!
     @param fmt format string
@@ -208,7 +214,7 @@ void exit_failure(const vmp_char *fmt,...);
 //! Opens a write stream file associated with the filedescriptor
 /*!
     @param fd fd input
-    @return file stream(except error)
+    @return file stream or except in case of failure
 */
 FILE *fd_stream(vmp_int fd);
 
@@ -221,10 +227,26 @@ void stream_write(FILE *f,vmp::str data);
 
 //!Close File stream assign (*f)=0
 /*!
-     @param pointer to pointer stream
+    @param pointer to pointer stream
 */
 void stream_close(FILE **f);
 
+//!Copy a file
+/*!
+    @param src source file
+    @param dst destination file
+    @return void or except in case of failure
+*/
+void copy_file(vmp::str src,vmp::str dst);
+
+//!Move a file
+/*!
+    @param src source file
+    @param dst destination file
+    @return void or except in case of failure
+*/
+void move_file(vmp::str src,vmp::str dst);
+
 }}
 
 #endif
