@@ -253,7 +253,7 @@ void execve_wrap(vmp::str filename,vmp_char *const argv[],vmp_char *const envp[]
 */
 vmp_int getopt_wrap(vmp_int argc, vmp_char *const argv[],vmp::str optstring);
 
-//Manipulates the underlying device parameters of socket interface to configure network device
+//!Manipulates the underlying device parameters of socket interface to configure network device
 /*!
     @param sock input socket
     @param ifname interface name
@@ -263,6 +263,19 @@ vmp_int getopt_wrap(vmp_int argc, vmp_char *const argv[],vmp::str optstring);
 */
 void ioctl_wrap_ifreq(vmp_int sock,vmp::str ifname,vmp_uint request,struct ifreq *ifr);
 
+//! Sets its argument as the seed for a new sequence of pseudo-random integers to be returned by rand_wrap()
+/*!
+    @param seed seed sequence
+*/
+void srand_wrap(vmp_uint seed);
+
+//! Function returns a pseudo-random integer in the range 0 to vmp::RANDMAX inclusive(see srand_wrap)
+/*!
+    @param hop number of jumps
+    @return a value between 0 and vmp::RANDMAX
+*/
+vmp_uint rand_wrap(vmp_uint hop=0);
+
 namespace fs {
 
 //!mode inode type
