@@ -160,12 +160,21 @@ vmp::str str_toxstr(vmp::str str,vmp::str delimiter);
 
 //!Convert a string from hexdecimal format to a string in normal format
 /*!
-     @param xstr input string hexadecimal format
-     @param delimiter byte delimiter
-     @return The converted string value,throw exception to error
+    @param xstr input string hexadecimal format
+    @param delimiter byte delimiter
+    @return The converted string value,throw exception to error
 */
 vmp::str xstr_tostr(vmp::str xstr,vmp::str delimiter);
 
+//! Generate substring
+/*!
+    @param str input string
+    @param pos position of the first character to be copied as a substring
+    @param len Number of characters to include in the substring
+    @return substring or or except in case of failure
+*/
+vmp::str str_sub(vmp::str str,vmp_index pos,vmp_size len);
+
 //! Search substring sub in str
 /*!
     @param str input string
@@ -174,6 +183,15 @@ vmp::str xstr_tostr(vmp::str xstr,vmp::str delimiter);
 */
 vmp_bool str_findsub(vmp::str str,vmp::str sub);
 
+//! Replace in text the find occurrences with sub
+/*!
+    @param text input text
+    @param occurrence to be replaced
+    @param string to be replaced at occurrences
+    @retun text with occurrences replaced
+*/
+vmp::str str_replace(vmp::str text,vmp::str find,vmp::str sub);
+
 //! Check if a string has ascii code characters <= 0x20 or >= 0x7E(\ n, \ t DEL SPACE etc ..)
 /*!
     @param str string input
@@ -211,13 +229,21 @@ vmp::str str_format_end(vmp::str content);
 */
 vmp::str str_extract_char(vmp::str str,vmp::str clist);
 
+//! Removes duplicate strings from the input vector
+/*!
+    @param svect input vector
+    @return a vector with all different strings    
+*/
+vmp::vector<vmp::str> str_remove_duplex(vmp::vector<vmp::str> svect);
+
 //!Check if there are regular expressions of types Basic POSIX grammar and case insensitive in a string and return them
 /*!
     @param str string to analize
     @param str_regex regular espression to search
+    @param true use case-insensitive mode, false use case-sensitive mode
     @return the vector of all matched strings
 */
-vmp::vector<vmp::str> str_regex_posix_icase(vmp::str str,vmp::str str_regex);
+vmp::vector<vmp::str> str_regex(vmp::str str,vmp::str str_regex,vmp_bool icase=false);
 
 }}}
 
